<?php

    /*
        QassimTwitterOAuth - The easy way to use Twitter API (v1.1).
            Written By: Qassim Hassan.
            Twitter: @QQQHZ
            Websites: wp-time.com | wp-plugins.in | qass.im
            E-Mail: qassim.pay@gmail.com
            Script Link: http://wp-time.com/twitter-rest-api-using-php-without-curl/
            Copyrights: (c) 2016 Qassim Hassan.
    */


include 'config.php';


function BaseString($url, $parameters, $method = null){
    if( empty($method) ){
        $method = 'GET';
    }

    $get_url = rawurlencode($url);

    $string = array();

    ksort($parameters);

    foreach ($parameters as $key => $value) {
        $string[] = "$key=" . rawurlencode($value);
    }

    return $method."&".$get_url."&".rawurlencode(implode('&', $string));
}


function AuthorizationOAuth($parameters){
    $oauth = '';

    foreach ($parameters as $key => $value) {
        $oauth .= $key.'="'.rawurlencode($value).'", ';
    }

    return array("Authorization: OAuth ".substr($oauth, 0,-2), 'Expect:');
}


function RequestToken($oauth, $url, $method){
    $header = AuthorizationOAuth($oauth);

    $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl, CURLOPT_HEADER, 0);
        curl_setopt($curl, CURLOPT_HTTPHEADER, $header);

        if( $method == 1 ){
            curl_setopt($curl, CURLOPT_POST, 1);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $oauth);
        }
        
        $response = curl_exec($curl);
    curl_close($curl);

    return $response;
}


function Request($url, $method, $key, $key_secret, $token, $token_secret, $parameters){
    $param = array(
                'oauth_consumer_key' => $key,
                'oauth_nonce' => time(),
                'oauth_signature_method' => 'HMAC-SHA1',
                'oauth_timestamp' => time(),
                'oauth_token' => $token,
                'oauth_version' => '1.0',
            );

    if( strtolower($method) == 'post' ){
        $get_method = 'POST';
    }elseif( strtolower($method) == 'delete' ){
        $get_method = 'DELETE';
    }else{
        $get_method = 'GET';
    }

    if( !empty($parameters) ){
        $array_merge = array_merge($param, $parameters);
        $the_param = $array_merge;
    }else{
        $the_param = $param;
    }

    $base_string = BaseString($url, $the_param, $get_method);

    $composite_key = $key_secret."&".$token_secret;

    $oauth_signature = base64_encode(hash_hmac('sha1', $base_string, $composite_key, true));

    $the_param['oauth_signature'] = $oauth_signature;

    if( $get_method == 'POST' or $get_method == "DELETE" ){
        $options = array('http' =>
                        array(
                            'method'  => $get_method,
                            'header' => "Content-Type: application/x-www-form-urlencoded\r\n",
                            'content'  => http_build_query($the_param)
                        )
                    );

        $context  = stream_context_create($options);

        $result = file_get_contents($url, false, $context);

        $json = json_decode($result, true);

        return $json;
    }

    else{
        $get_url = $url."?".http_build_query($the_param);
        $result = file_get_contents($get_url);        
        $json = json_decode($result, true);
        return $json;
    }
}